--[[
    Baldrick_Classic_Neutral by LordFarlander
    Version 1.5.4
    $Revision: 3 $
]]--

--[[
Copyright (c) 2008, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local Baldrick = _G["Baldrick"];

if( not Baldrick ) then
    error( L["%s requires %s"]:format( "Baldrick_Classic_Horde", "Baldrick" ) );
    return;
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Baldrick_Classic" );
local LBZ = LibStub( "LibBabble-Zone-3.0" );

if( LBZ ) then
    LBZ = LBZ:GetUnstrictLookupTable();
end--if

local ZONES = {};
setmetatable( ZONES, {
    __index = function( self, key )
            local returnVal = LBZ and LBZ[key];

            if( not returnVal ) then
                returnVal = L[key];
            end--if
            return returnVal;
        end } );

local NPCS = L;
local OBJECTIVES = L;

local function IsTargetAliveAndNotTapped()
    return ( not UnitIsDead( "playertarget" ) ) and
       ( UnitIsTappedByPlayer( "playertarget" ) or ( not UnitIsTapped( "playertarget" ) ) );
end--IsTargetAliveAndNotTapped()

local function IsTargetDead()
    return UnitIsDead( "playertarget" );
end--IsTargetDead()

local quests = {
    --Eastern Kingdoms
    --Blackrock Mountain
    {
        --Egg Collection
        questIDs = 4735,
        --Collectronic Module
        questItems = { default = { questItem = 12287, questItemCount = 1, }, },
        subZones = ZONES["Rookery"],
    },
    --Blackrock Depths
    {
        --The Challenge
        questIDs = 9015,
        --Banner of Provocation
        questItems = { default = { questItem = 21986, questItemCount = 1, }, },
        subZones = ZONES["Ring of the Law"],
    },
    --Blackrock Spire
    {
        --A Taste of Flame
        questIDs = 4024,
        --Altered Black Dragonflight Molt
        questItems = { default = { questItem = 11231, questItemCount = 1, }, },
        target = NPCS["Bael'Gar"],
        func = IsTargetDead,
    },
    {
        --Kibler's Exotic Pets
        questIDs = 4729,
        --Empty Worg Pup Cage
        questItems = { default = { questItem = 12262, questItemCount = 1, }, },
        target = NPCS["Bloodaxe Worg Pup"],
        func = IsTargetDead,
    },
    {
        --The Left Piece of Lord Valthalak's Amulet
        --The Right Piece of Lord Valthalak's Amulet
        questIDs = { 8966, 8989 },
        --Brazier of Beckoning
        questItems = { default = { questItem = 22049, questItemCount = 1, }, },
        subZones = ZONES["Blackrock Spire"],
    },
    {
        --Mea Culpa, Lord Valthalak
        questIDs = 8995,
        --Brazier of Beckoning
        questItems = { default = { questItem = 22056, questItemCount = 1, }, },
        subZones = ZONES["Blackrock Spire"],
    },
    {
        --Mea Culpa, Lord Valthalak
        questIDs = 8995,
        --Lord Valthalak's Amulet
        questItems = { default = { questItem = 22048, questItemCount = 1, }, },
        target = NPCS["Lord Valthalak"],
        func = IsTargetDead,
    },
    --Blasted Lands
    {
        --You Are Rakh'likh, Demon
        questIDs = 3628,
        --Ward of the Defiler
        questItems = { default = { questItem = 10757, questItemCount = 1, }, },
        subZones = ZONES["Rise of the Defiler"],
    },
    --Burning Steppes
    {
        --Broodling Essence
        questIDs = 4726,
        --Draco-Incarcinatrix 900
        questItems = { default = { questItem = 12284, questItemCount = 1, }, },
        target = NPCS["Black Broodling"],
        func = IsTargetAliveAndNotTapped,
    },
    --Eastern Plaguelands
    {
        --The Battle of Darrowshire
        questIDs = 5721,
        --Relic Bundle
        questItems = { default = { questItem = 15209, questItemCount = 1, }, },
        subZones = ZONES["Darrowshire"],
    },
    {
        --When Smokey Sings, I Get Violent
        questIDs = 6041,
        --Smokey's Special Compound
        questItems = { default = { questItem = 15736, questItemCount = 1, }, },
        subZones = ZONES["Plaguewood"],
    },
    --Scholomance
    {
        --The Lich, Ras Frostwhisper
        questIDs = 5466,
        --Soulbound Keepsake
        questItems = { default = { questItem = 13752, questItemCount = 1, }, },
        target = NPCS["Ras Frostwhisper"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Dawn's Gambit
        questIDs = 6041,
        --Dawn's Gambit
        questItems = { default = { questItem = 12368, questItemCount = 1, }, },
        subZones = ZONES["Viewing Room"],
    },
    {
        --The Left Piece of Lord Valthalak's Amulet
        --The Right Piece of Lord Valthalak's Amulet
        questIDs = { 8969, 8992, },
        --Brazier of Beckoning
        questItems = { default = { questItem = 22052, questItemCount = 1, }, },
        subZones = ZONES["Scholomance"],
    },
    --Searing Gorge
    {
        --Set Them Ablaze!
        questIDs = 3463,
        --Torch of Retribution
        questItems = { default = { questItem = 10515, questItemCount = 1, }, },
        subZones = ZONES["Searing Gorge"],
    },
    --Western Plaguelands
    {
        --A Matter of Time
        questIDs = 4971,
        --Temporal Displacer
        questItems = { default = { questItem = 12627, questItemCount = 1, }, },
        subZones = ZONES["Andorhal"],
    },
    {
        --Two Halves Become One
        questIDs = 5051,
        --Good Luck Other-Half-Charm, Good Luck Half-Charm
        questItems = { default = { questItem = 12722, questItemCount = 1, }, { questItem = 12721, questItemCount = 1, }, },
    },
    --Stratholme
    {
        --The Left Piece of Lord Valthalak's Amulet
        --The Right Piece of Lord Valthalak's Amulet
        questIDs = { 8968, 8991, },
        --Brazier of Beckoning
        questItems = { default = { questItem = 22051, questItemCount = 1, }, },
        subZones = ZONES["Scarlet Bastion"],
    },
    {
        --The Restless Souls
        questIDs = 5282,
        --Egan's Blaster
        questItems = { default = { questItem = 13289, questItemCount = 1, }, },
        target = NPCS["Spectral Citizen"] .. "|" .. NPCS["Restless Spirit"],
        func = IsTargetAliveAndNotTapped,
    },

    --Kalimdor
    --Barrens
    {
        --Blueleaf Tubers
        questIDs = 1221,
        --Snufflenose Command Stick
        questItems = { default = { questItem = 6684, questItemCount = 1, }, },
        target = NPCS["Snufflenose Gopher"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Blueleaf Tubers
        questIDs = 1221,
        --Crate With Holes
        questItems = { default = { questItem = 5880, questItemCount = 1, }, },
        subZones = ZONES["Razorfen Kraul"],
    },
    --Desolace
    {
        --Ghost-o-plasm Round Up
        questIDs = 6134,
        --Crate of Ghost Magnets
        questItems = { default = { questItem = 15848, questItemCount = 1, }, },
        subZones = ZONES["Valley of Bones"],
    },
    {
        --Kodo Roundup
        questIDs = 5561,
        --Kodo Kombobulator
        questItems = { default = { questItem = 13892, questItemCount = 1, }, },
        target = NPCS["Ancient Kodo"] .. "|" .. NPCS["Aged Kodo"] .. "|" .. NPCS["Dying Kodo"],
        func = IsTargetAliveAndNotTapped,
    },
    --Dustwallow Marsh
    {
        --Challenge to the Black Flight
        questIDs = 11162,
        --Stonemaul Banner
        questItems = { default = { questItem = 33095, questItemCount = 1, }, },
        subZones = ZONES["Onyxia's Lair"],
    },
    {
        --Cleansing Witch Hill
        questIDs = 11183,
        --Witchbane Torch
        questItems = { default = { questItem = 33113, questItemCount = 1, }, },
        subZones = ZONES["Swamplight Manor"],
    },
    {
        --Spirits of Stonemaul Hold
        questIDs = 11159,
        --Energized Totem
        questItems = { default = { questItem = 33091, questItemCount = 1, }, },
        subZones = ZONES["Stonemaul Ruins"],
    },
    {
        --The Grimtotem Weapon
        questIDs = 11169,
        --Captured Totem
        questItems = { default = { questItem = 33101, questItemCount = 1, }, },
        subZones = ZONES["Quagmire"],
    },
    {
        --Corrosion Prevention
        questIDs = 11174,
        --Ooze Buster
        questItems = { default = { questItem = 33113, questItemCount = 1, }, },
        target = NPCS["Bubbling Swamp Ooze"] .. "|" .. NPCS["Acidic Swamp Ooze"],
    },
    --Felwood
    {
        --Collection of the Corrupt Water
        questIDs = 5157,
        --Empty Canteen
        questItems = { default = { questItem = 12922, questItemCount = 1, }, },
        subZones = ZONES["Jaedenar"],
    },
    {
        --Dousing the Flames of Protection
        questIDs = 5165,
        --Purified Moonwell Water
        questItems = { default = { questItem = 12906, questItemCount = 1, }, },
        subZones = ZONES["Jaedenar"],
    },
    --Feralas
    {
        --Zapped Giants
        --Again With the Zapped Giants
        questIDs = { 7003, 7725 },
        --Zorbin's Ultra-Shrinker
        questItems = { default = { questItem = 18904, questItemCount = 1, }, },
        target = NPCS["Land Walker"] .. "|" .. NPCS["Cliff Giant"] .. "|" .. NPCS["Sea Giant"],
    },
    --Dire Maul
    {
        --The Left Piece of Lord Valthalak's Amulet
        --The Right Piece of Lord Valthalak's Amulet
        questIDs = { 8967, 8990 },
        --Brazier of Beckoning
        questItems = { default = { questItem = 22050, questItemCount = 1, }, },
        subZones = ZONES["Blackrock Spire"],
    },
    --Silithus
    {
        --The Calling
        questIDs = 8315,
        --Glyphs of Calling
        questItems = { default = { questItem = 20464, questItemCount = 1, }, },
        subZones = ZONES["Bones of Grakkarond"],
    },
    --Tanaris
    {
        --Gadgetzan Water Survey
        questIDs = 992,
        --Untapped Dowsing Widget
        questItems = { default = { questItem = 8584, questItemCount = 1, }, },
        subZones = ZONES["Sandsorrow Watch"],
    },
    {
        --Hunting for Ectoplasm
        questIDs = 8924,
        --Ectoplasmic Distiller, Goblin Rocket Fuel
        questItems = { default = { questItem = 21946, questItemCount = 1, }, { questItem = 9061, questItemCount = 1, }, },
        subZones = ZONES["Silithus"],
    },
    {
        --Hunting for Ectoplasm
        questIDs = 8924,
        --Ectoplasmic Distiller, Goblin Rocket Fuel
        questItems = { default = { questItem = 21946, questItemCount = 1, }, { questItem = 9061, questItemCount = 1, }, },
        subZones = ZONES["Silithus"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 21937 ) ) );
            end,
    },
    {
        --Hunting for Ectoplasm
        questIDs = 8924,
        --Ectoplasmic Distiller, Goblin Rocket Fuel
        questItems = { default = { questItem = 21946, questItemCount = 1, }, { questItem = 9061, questItemCount = 1, }, },
        subZones = ZONES["Winterspring"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 21936 ) ) );
            end,
    },
    {
        --Hunting for Ectoplasm
        questIDs = 8924,
        --Ectoplasmic Distiller, Goblin Rocket Fuel
        questItems = { default = { questItem = 21946, questItemCount = 1, }, { questItem = 9061, questItemCount = 1, }, },
        subZones = ZONES["Eastern Plaguelands"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 21935 ) ) );
            end,
    },
    {
        --Pawn Captures Queen
        questIDs = 4507,
        --Gorishi Queen Lure
        questItems = { default = { questItem = 11833, questItemCount = 1, }, },
        subZones = ZONES["Un'Goro Crater"],
    },
    {
        --Screecher Spirits
        questIDs = 3520,
        --Yeh'kinya's Bramble
        questItems = { default = { questItem = 10699, questItemCount = 1, }, },
        target = NPCS["Vale Screecher"] .. "|" .. NPCS["Rogue Vale Screecher"],
        func = IsTargetDead,
    },
    {
        --The Only Prescription
        questIDs = 8620,
        --Magical Book Binding, Draconic for Dummies
        questItems = { default = { questItem = 21112, questItemCount = 1, }, { questItem = 21103, questItemCount = 1, }, { questItem = 21104, questItemCount = 1, }, { questItem = 21105, questItemCount = 1, }, { questItem = 21106, questItemCount = 1, }, { questItem = 21107, questItemCount = 1, }, { questItem = 21108, questItemCount = 1, }, { questItem = 21109, questItemCount = 1, }, { questItem = 21110, questItemCount = 1, }, },
    },
    --Caverens of Time: Old Hisbrad
    {
        --Taretha's Diversion
        questIDs = 10283,
        --Pack of Incendiary Bombs
        questItems = { default = { questItem = 25853, questItemCount = 1, }, },
        subZones = ZONES["Durnholde Keep"],
    },
    --Un'Goro Crater
    {
        --Alien Ecology
        questIDs = 3883,
        --Unused Scraping Vial
        questItems = { default = { questItem = 11132, questItemCount = 1, }, },
        subZones = ZONES["Un'Goro Crater"],
    },
    {
        --Aquementas
        questIDs = 4005,
        --Book of Aquor
        questItems = { default = { questItem = 11169, questItemCount = 1, }, },
        subZones = ZONES["Lost Rigger Cove"],
    },
    {
        --Finding the Source
        questIDs = 974,
        --Krakle's Thermometer
        questItems = { default = { questItem = 12472, questItemCount = 1, }, },
        subZones = ZONES["Fire Plume Ridge"],
    },
    {
        --It's Dangerous to Go Alone
        questIDs = 3962,
        --Silver Totem of Aquementas
        questItems = { default = { questItem = 11522, questItemCount = 1, }, },
        target = NPCS["Blazerunner"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Meet at the Grave
        questIDs = 3912,
        --Videre Elixir
        questItems = { default = { questItem = 11243, questItemCount = 1, }, },
        subZones = ZONES["Tanaris"],
        func = function()
                return not UnitIsDead( "player" );
            end,
    },
    --Winterspring
    {
        --Shy-Rotam
        questIDs = 5056,
        --Sacred Frostsaber Meat
        questItems = { default = { questItem = 12733, questItemCount = 1, }, },
        subZones = ZONES["Frostsaber Rock"],
    },
    {
        --Are We There, Yeti?
        questIDs = 5163,
        --Umi's Mechanical Yeti
        questItems = { default = { questItem = 12928, questItemCount = 1, }, },
        target = NPCS["Legacki"] .. "|" .. NPCS["Sprinkle"] .. "|" .. NPCS["Quixxil"],
        func = function()
                return ( ( target == NPCS["Legacki"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Scare Legacki"] ) ) ) or
                    ( ( target == NPCS["Sprinkle"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Scare Sprinkle"] ) ) ) or
                    ( ( target == NPCS["Quixxil"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Scare Quixxil"] ) ) );
            end,
    },
};

Baldrick:RegisterQuestModule( L["Classic Neutral Quests"], quests, nil );
